import sqlite3
import os
import re

# פונקציה שמסננת תווים לא חוקיים לשם הקובץ
def sanitize_title(title):
    return re.sub(r'[\/:*?"<>|]', '', title)

# פונקציה לשליפת title ושם הפודקאסט על פי הנתיב לקובץ
def get_title_and_podcast(database_path, file_url):
    print(f"בודק עבור file_url: {file_url}")
    conn = sqlite3.connect(database_path)
    cursor = conn.cursor()

    try:
        # בדיקה אם הערך של file_url קיים בטבלת FeedMedia וקבלת feeditem אם כן
        cursor.execute("SELECT feeditem FROM FeedMedia WHERE file_url = ?", (file_url,))
        feeditem_row = cursor.fetchone()
        if feeditem_row is None:
            print(f"לא נמצא פרק עבור {file_url}.")
            return None, None
        feeditem = feeditem_row[0]

        # קבלת title ו-feed_id מתוך FeedItems
        cursor.execute("SELECT title, feed FROM FeedItems WHERE id = ?", (feeditem,))
        title_row = cursor.fetchone()
        if title_row is None:
            print(f"לא נמצא title או feed_id עבור feeditem {feeditem}.")
            return None, None
        title, feed_id = title_row

        # קבלת שם הפודקאסט מתוך Feeds לפי feed_id
        cursor.execute("SELECT title FROM Feeds WHERE id = ?", (feed_id,))
        podcast_row = cursor.fetchone()
        if podcast_row is None:
            print(f"לא נמצא פודקאסט עבור feed_id {feed_id}.")
            return None, None
        podcast_name = podcast_row[0]

        return title, podcast_name

    except sqlite3.Error as e:
        print("שגיאה בעת הגישה למסד הנתונים:", e)
        return None, None
    finally:
        conn.close()

# פונקציה למעבר על הקבצים ושינוי שמם בתיקיות לפי שם הפודקאסט
def rename_files(database_path, base_directory):
    for root, dirs, files in os.walk(base_directory):
        for filename in files:
            full_file_path = os.path.join(root, filename)
            relative_file_path = full_file_path.replace(base_directory, "/storage/emulated/0/Android/data/de.danoeh.antennapod/files/media").replace("\\", "/")

            title, podcast_name = get_title_and_podcast(database_path, relative_file_path)
            if title and podcast_name:
                sanitized_title = sanitize_title(title)
                sanitized_podcast_name = sanitize_title(podcast_name)

                # יצירת תיקייה ישירות בתוך base_directory עם שם הפודקאסט
                podcast_dir = os.path.join(base_directory, sanitized_podcast_name)
                if not os.path.exists(podcast_dir):
                    os.makedirs(podcast_dir)

                # יצירת הנתיב החדש בתוך תיקיית הפודקאסט
                new_file_path = os.path.join(podcast_dir, f"{sanitized_title}.mp3")
                try:
                    os.rename(full_file_path, new_file_path)
                    print(f"שינוי שם: {filename} -> {sanitized_podcast_name}/{sanitized_title}.mp3")
                except Exception as e:
                    print(f"לא ניתן לשנות שם עבור {filename}: {e}")
# דוגמה לשימוש
database_path = "Antennapod.db"
base_directory = "E:/pods/files/media"
rename_files(database_path, base_directory)